/* Load the ACS 5-year Geo files for each state */

options sysprintfont=("Courier New" 8) leftmargin=0.75in nocenter;

/* Specify data path here for portability: */
%let pathin=J:\Census_Stuff\ACS2011_5yr\DownloadCenter_2_giant_files\2011_ACS_Geography_Files\;
%let pathsas=J:\Census_Stuff\ACS2011_5yr\;
%let pathpdf=J:\Census_Stuff\ACS2011_5yr\SASRpts\;
%let acsendyear=2011;

%let obslimit=;
/* %let obslimit=obs=1000; /* For debugging */

libname CensSAS "&pathsas.SASData";
ods pdf file="&pathpdf.SAS01_GeoStats.pdf";

/* Create a dataset with the state abbreviations and Fips codes */

proc sort data=sashelp.zipcode nodupkey out=statetbl;
   by state statecode;
run;

data statetbl;
   set statetbl;
   keep state statecode;
   if state <= 56 or state = 72; /* Just the 50 states, DC, and Puerto Rico */
run;

%macro readGeo;
/* Read in a state ACS Geo File */
/* Uses the Geo file from Tracts_Block_Groups_Only but same as All_Other_Geogs version */
data tempGeo;
   INFILE "&pathin.g&acsendyear.5&statem..txt"
        DSD TRUNCOVER LRECL=32767 &obslimit;
   LABEL STUSAB='State/U.S.-Abbreviation (USPS)'
         SUMLEV='Summary Level'
         GEOCOMP='Geographic Component'
         LOGRECNO='Logical Record Number'
         STATE='State (FIPS)'
         COUNTY='County (FIPS)'
         PLACE='Place (FIPS)'
         TRACT='Census Tract'
         BLKGRP='Block Group'
         UR='Urban/Rural'
         GEOID='Geographic Identifier'
         NAME='Area Name'
         ;
   INPUT
    @7 STUSAB $2.
    @9 SUMLEV $3.
    @12 GEOCOMP $2.
    @14 LOGRECNO 7. /* Note: numeric variable for match with data tables */
    @26 STATE $2.
    @28 COUNTY $3.
    @36 PLACE $5.
    @41 TRACT $6.
    @47 BLKGRP $1.
    @156 UR $1.
    @179 GEOID $40.
    @219 NAME $200.
    ;
   if SUMLEV = '140';  /* Just keep tract records */
   /* Fix the handful of Puerto Rico records that have blank state FIPS codes: */
   if (STUSAB = 'PR') & (STATE = '') then STATE = '72';
run;
proc datasets nolist force;
   append out=allGeo data=tempGeo;
   quit;
run;
%mend readGeo;

%macro allstates;
   %do j=1 %to 52;
   /* Read the state table 52 times, find the jth record, */
   /*   and call readgeo using the statecode of jth record. */
   data _null_;
      set statetbl;
      if _n_=&j;
      call symputx('statem', statecode);
      %readGeo;
   run;
   %end;
%mend allstates;

/* For debugging, just do AL */
/* %let statem=AL; */
/* %readGeo; */

/* Before we start, delete any previous version */
proc datasets library=CensSAS nolist ;
   delete allGeo;
   quit;
run;

%allstates;

/* Sort and check for duplicate keys - should not be any */
proc sort data=allGeo nodupkey out=CensSAS.allGeo;
   by STUSAB LOGRECNO;
run;

/* Stats from the ACS Geo file */
proc freq data = CensSAS.allGeo;
    table STATE*STUSAB / list missing;
    table SUMLEV*GEOCOMP / list;
run;

/* Number of distinct values for each variable */
ods select nlevels;
proc freq data=CensSAS.allGeo nlevels;
   table STUSAB;
run;

ods pdf close;
