/* Extract ACS table B00001 (Samples) for tracts (SUMLEV 140) */

options sysprintfont=("Courier New" 8) leftmargin=0.75in nocenter;

/* Specify ACS sequence number, the number of variables, and the table number: */
%let seqnum=001;  * The sequence number of file that contain the table you want (3 digits);
%let firstvar=7;  * Position of the first variable in the table;
%let tablenum=B00001_samps; * The ACS table number with descriptive suffix;
/* Example parameters seqnum=049, firstvar=219 for table C17002 (Ratio of Income to Poverty Level) */

/* Specify data path here for portability: */
%let pathsas=J:\Census_Stuff\ACS2011_5yr\;
%let pathpdf=J:\Census_Stuff\ACS2011_5yr\SASRpts\;

%let obslimit=;
/* %let obslimit=obs=10000; /* For debugging */

libname CensSAS "&pathsas.SASData";
ods pdf file="&pathpdf.SAS21_Extract_&tablenum._Tract.pdf";

data Table_&tablenum._tract;
   set CensSAS.AllData_Seq&seqnum._tracts (&obslimit);
   if SUMLEV = '140';
   StCntyTract = STATE || COUNTY || TRACT;
   Popsamps = var%eval(&firstvar+0);
   MOE_popsamps = mvar%eval(&firstvar+0);
   DROP GEOCOMP LOGRECNO PLACE BLKGRP UR GEOID SEQUENCE
        var: mvar:;
   LABEL
    Popsamps = 'Unweighted population sample count'
    MOE_popsamps = 'Margin of error unweighted population sample count (-1)'
    ;
run;

/* Sort and check for duplicates: */
proc sort data=Table_&tablenum._tract nodupkey out=CensSAS.Table_&tablenum._tract;
   by StCntyTract;
run;

/* Stats */
proc freq data=CensSAS.Table_&tablenum._tract;
   table STUSAB;
   table MOE_popsamps / missing; /* Should all be -1 */
run;

/* Histogram of samples counts */
proc univariate data=CensSAS.Table_&tablenum._tract /* noprint */ ;
   var Popsamps;
   histogram Popsamps;
run;

/* Horizontal bar chart */
proc chart data=CensSAS.Table_&tablenum._tract /* noprint */ ;
   hbar Popsamps / missing;
run;

/* Number of distinct values for each variable */
ods select nlevels;
proc freq data=CensSAS.Table_&tablenum._tract nlevels;
   table STUSAB;
   table MOE_popsamps; /* Should all be -1 */
run;

ods pdf close;

