/* Extract ACS table B02001 (Race) for tracts (SUMLEV 140) */

options sysprintfont=("Courier New" 8) leftmargin=0.75in nocenter;

/* Specify ACS sequence number, the number of variables, and the table number: */
%let seqnum=004;  * The sequence number of file that contain the table you want (3 digits);
%let firstvar=7;  * Position of the first variable in the table;
%let tablenum=B02001_race; * The ACS table number with descriptive suffix;
/* Example parameters seqnum=049, firstvar=219 for table C17002 (Ratio of Income to Poverty Level) */

/* Specify data path here for portability: */
%let pathsas=J:\Census_Stuff\ACS2011_5yr\;
%let pathpdf=J:\Census_Stuff\ACS2011_5yr\SASRpts\;

%let obslimit=;
/* %let obslimit=obs=10000; /* For debugging */

libname CensSAS "&pathsas.SASData";
ods pdf file="&pathpdf.SAS21_Extract_&tablenum._Tract.pdf";

data Table_&tablenum._tract;
   set CensSAS.AllData_Seq&seqnum._tracts (&obslimit);
   if SUMLEV = '140';
   StCntyTract = STATE || COUNTY || TRACT;
   Est_tot_pop    = var%eval(&firstvar+0);
   Est_white      = var%eval(&firstvar+1);
   Est_black      = var%eval(&firstvar+2);
   Est_AIAN       = var%eval(&firstvar+3);
   Est_Asian      = var%eval(&firstvar+4);
   Est_NHOPI      = var%eval(&firstvar+5);
   Est_other      = var%eval(&firstvar+6);
   Est_2plus      = var%eval(&firstvar+7);
   Est_2races     = var%eval(&firstvar+8);
   Est_2noth3plus = var%eval(&firstvar+9);
   MOE_tot_pop    = mvar%eval(&firstvar+0);
   MOE_white      = mvar%eval(&firstvar+1);
   MOE_black      = mvar%eval(&firstvar+2);
   MOE_AIAN       = mvar%eval(&firstvar+3);
   MOE_Asian      = mvar%eval(&firstvar+4);
   MOE_NHOPI      = mvar%eval(&firstvar+5);
   MOE_other      = mvar%eval(&firstvar+6);
   MOE_2plus      = mvar%eval(&firstvar+7);
   MOE_2races     = mvar%eval(&firstvar+8);
   MOE_2noth3plus = mvar%eval(&firstvar+9);
   DROP GEOCOMP LOGRECNO PLACE BLKGRP UR GEOID SEQUENCE
        var: mvar:;
   LABEL
    Est_tot_pop = 'Estimate total pop'
    Est_white   = 'Estimate White alone'
    Est_black   = 'Estimate Black or African American alone'
    Est_AIAN    = 'Estimate American Indian and Alaska Native alone'
    Est_Asian   = 'Estimate Asian alone'
    Est_NHOPI   = 'Estimate Native Hawaiian and Other Pacific Islander alone'
    Est_other   = 'Estimate Some other race alone'
    Est_2plus   = 'Estimate Two or more races - total'
    Est_2races  = 'Estimate Two races including Some other race'
    Est_2noth3plus = 'Estimate Two races excluding Some other race, and three or more races'
    MOE_tot_pop = 'Margin of error total pop'
    MOE_white   = 'Margin of error White alone'
    MOE_black   = 'Margin of error Black or African American alone'
    MOE_AIAN    = 'Margin of error American Indian and Alaska Native alone'
    MOE_Asian   = 'Margin of error Asian alone'
    MOE_NHOPI   = 'Margin of error Native Hawaiian and Other Pacific Islander alone'
    MOE_other   = 'Margin of error Some other race alone'
    MOE_2plus   = 'Margin of error Two or more races - total'
    MOE_2races  = 'Margin of error Two races including Some other race'
    MOE_2noth3plus = 'Margin of error Two races excluding Some other race, and three or more races'
    ;
run;

/* Sort and check for duplicates: */
proc sort data=Table_&tablenum._tract nodupkey out=CensSAS.Table_&tablenum._tract;
   by StCntyTract;
run;

/* Stats by state */
proc freq data=CensSAS.Table_&tablenum._tract;
   table STUSAB;
run;

/* Number of distinct values for each variable */
ods select nlevels;
proc freq data=CensSAS.Table_&tablenum._tract nlevels;
   tables STUSAB;
run;

ods pdf close;

