/* Extract ACS table B03002 (Hispanic by race) for tracts (SUMLEV 140) */

options sysprintfont=("Courier New" 8) leftmargin=0.75in nocenter;

/* Specify ACS sequence number, the number of variables, and the table number: */
%let seqnum=005;  * The sequence number of file that contain the table you want (3 digits);
%let firstvar=38;  * Position of the first variable in the table;
%let tablenum=B03002_hisp; * The ACS table number with descriptive suffix;
/* Example parameters seqnum=049, firstvar=219 for table C17002 (Ratio of Income to Poverty Level) */

/* Specify data path here for portability: */
%let pathsas=J:\Census_Stuff\ACS2011_5yr\;
%let pathpdf=J:\Census_Stuff\ACS2011_5yr\SASRpts\;

%let obslimit=;
/* %let obslimit=obs=10000; /* For debugging */

libname CensSAS "&pathsas.SASData";
ods pdf file="&pathpdf.SAS21_Extract_&tablenum._Tract.pdf";

data Table_&tablenum._tract;
   set CensSAS.AllData_Seq&seqnum._tracts (&obslimit);
   if SUMLEV = '140';
   StCntyTract = STATE || COUNTY || TRACT;
   Est_tot_pop      = var%eval(&firstvar+0);
   Est_nHisp_tot    = var%eval(&firstvar+1);
   Est_nHisp_white  = var%eval(&firstvar+2);
   Est_nHisp_black  = var%eval(&firstvar+3);
   Est_nHisp_AIAN   = var%eval(&firstvar+4);
   Est_nHisp_Asian  = var%eval(&firstvar+5);
   Est_nHisp_NHOPI  = var%eval(&firstvar+6);
   Est_nHisp_other  = var%eval(&firstvar+7);
   Est_nHisp_2plus  = var%eval(&firstvar+8);
   Est_nHisp_2races = var%eval(&firstvar+9);
   Est_nHisp_2noth3plus= var%eval(&firstvar+10);
   Est_Hisp_tot     = var%eval(&firstvar+11);
   Est_Hisp_white   = var%eval(&firstvar+12);
   Est_Hisp_black   = var%eval(&firstvar+13);
   Est_Hisp_AIAN    = var%eval(&firstvar+14);
   Est_Hisp_Asian   = var%eval(&firstvar+15);
   Est_Hisp_NHOPI   = var%eval(&firstvar+16);
   Est_Hisp_other   = var%eval(&firstvar+17);
   Est_Hisp_2plus   = var%eval(&firstvar+18);
   Est_Hisp_2races  = var%eval(&firstvar+19);
   Est_Hisp_2noth3plus= var%eval(&firstvar+20);
   MOE_tot_pop      = mvar%eval(&firstvar+0);
   MOE_nHisp_tot    = mvar%eval(&firstvar+1);
   MOE_nHisp_white  = mvar%eval(&firstvar+2);
   MOE_nHisp_black  = mvar%eval(&firstvar+3);
   MOE_nHisp_AIAN   = mvar%eval(&firstvar+4);
   MOE_nHisp_Asian  = mvar%eval(&firstvar+5);
   MOE_nHisp_NHOPI  = mvar%eval(&firstvar+6);
   MOE_nHisp_other  = mvar%eval(&firstvar+7);
   MOE_nHisp_2plus  = mvar%eval(&firstvar+8);
   MOE_nHisp_2races = mvar%eval(&firstvar+9);
   MOE_nHisp_2noth3plus= mvar%eval(&firstvar+10);
   MOE_Hisp_tot     = mvar%eval(&firstvar+11);
   MOE_Hisp_white   = mvar%eval(&firstvar+12);
   MOE_Hisp_black   = mvar%eval(&firstvar+13);
   MOE_Hisp_AIAN    = mvar%eval(&firstvar+14);
   MOE_Hisp_Asian   = mvar%eval(&firstvar+15);
   MOE_Hisp_NHOPI   = mvar%eval(&firstvar+16);
   MOE_Hisp_other   = mvar%eval(&firstvar+17);
   MOE_Hisp_2plus   = mvar%eval(&firstvar+18);
   MOE_Hisp_2races  = mvar%eval(&firstvar+19);
   MOE_Hisp_2noth3plus= mvar%eval(&firstvar+20);
   DROP GEOCOMP LOGRECNO PLACE BLKGRP UR GEOID SEQUENCE
        var: mvar:;
   LABEL
    Est_tot_pop = 'Estimate total pop'
    Est_nHisp_tot    = 'Estimate not Hispanic or Latino total'
    Est_nHisp_white  = 'Estimate not Hispanic White alone'
    Est_nHisp_black  = 'Estimate not Hispanic Black or African American alone'
    Est_nHisp_AIAN   = 'Estimate not Hispanic American Indian and Alaska Native alone'
    Est_nHisp_Asian  = 'Estimate not Hispanic Asian alone'
    Est_nHisp_NHOPI  = 'Estimate not Hispanic Native Hawaiian and Other Pacific Islander alone'
    Est_nHisp_other  = 'Estimate not Hispanic Some other race alone'
    Est_nHisp_2plus  = 'Estimate not Hispanic Two or more races:'
    Est_nHisp_2races = 'Estimate not Hispanic Two races including Some other race'
    Est_nHisp_2noth3plus= 'Estimate not Hispanic Two races excluding Some other race, and three or more races'
    Est_Hisp_tot    = 'Estimate Hispanic or Latino total'
    Est_Hisp_white  = 'Estimate Hispanic White alone'
    Est_Hisp_black  = 'Estimate Hispanic Black or African American alone'
    Est_Hisp_AIAN   = 'Estimate Hispanic American Indian and Alaska Native alone'
    Est_Hisp_Asian  = 'Estimate Hispanic Asian alone'
    Est_Hisp_NHOPI  = 'Estimate Hispanic Native Hawaiian and Other Pacific Islander alone'
    Est_Hisp_other  = 'Estimate Hispanic Some other race alone'
    Est_Hisp_2plus  = 'Estimate Hispanic Two or more races:'
    Est_Hisp_2races = 'Estimate Hispanic Two races including Some other race'
    Est_Hisp_2noth3plus= 'Estimate Hispanic Two races excluding Some other race, and three or more races'
    MOE_tot_pop = 'Margin of error total pop'
    MOE_nHisp_tot    = 'Margin of error not Hispanic or Latino total'
    MOE_nHisp_white  = 'Margin of error not Hispanic White alone'
    MOE_nHisp_black  = 'Margin of error not Hispanic Black or African American alone'
    MOE_nHisp_AIAN   = 'Margin of error not Hispanic American Indian and Alaska Native alone'
    MOE_nHisp_Asian  = 'Margin of error not Hispanic Asian alone'
    MOE_nHisp_NHOPI  = 'Margin of error not Hispanic Native Hawaiian and Other Pacific Islander alone'
    MOE_nHisp_other  = 'Margin of error not Hispanic Some other race alone'
    MOE_nHisp_2plus  = 'Margin of error not Hispanic Two or more races:'
    MOE_nHisp_2races = 'Margin of error not Hispanic Two races including Some other race'
    MOE_nHisp_2noth3plus= 'Margin of error not Hispanic Two races excluding Some other race, and three or more races'
    MOE_Hisp_tot    = 'Margin of error Hispanic or Latino total'
    MOE_Hisp_white  = 'Margin of error Hispanic White alone'
    MOE_Hisp_black  = 'Margin of error Hispanic Black or African American alone'
    MOE_Hisp_AIAN   = 'Margin of error Hispanic American Indian and Alaska Native alone'
    MOE_Hisp_Asian  = 'Margin of error Hispanic Asian alone'
    MOE_Hisp_NHOPI  = 'Margin of error Hispanic Native Hawaiian and Other Pacific Islander alone'
    MOE_Hisp_other  = 'Margin of error Hispanic Some other race alone'
    MOE_Hisp_2plus  = 'Margin of error Hispanic Two or more races:'
    MOE_Hisp_2races = 'Margin of error Hispanic Two races including Some other race'
    MOE_Hisp_2noth3plus= 'Margin of error Hispanic Two races excluding Some other race, and three or more races'
    ;
run;

/* Sort and check for duplicates: */
proc sort data=Table_&tablenum._tract nodupkey out=CensSAS.Table_&tablenum._tract;
   by StCntyTract;
run;

/* Stats by state */
proc freq data=CensSAS.Table_&tablenum._tract;
   table STUSAB;
run;

/* Number of distinct values for each variable */
ods select nlevels;
proc freq data=CensSAS.Table_&tablenum._tract nlevels;
   tables STUSAB;
run;

ods pdf close;

