/* Extract ACS table B05012 (Foreign Born) for tracts (SUMLEV 140) */

options sysprintfont=("Courier New" 8) leftmargin=0.75in nocenter;

/* Specify ACS sequence number, the number of variables, and the table number: */
%let seqnum=012;  * The sequence number of file that contain the table you want (3 digits);
%let firstvar=69;  * Position of the first variable in the table;
%let tablenum=B05012_forborn; * The ACS table number with descriptive suffix;
/* Example parameters seqnum=049, firstvar=219 for table C17002 (Ratio of Income to Poverty Level) */

/* Specify data path here for portability: */
%let pathsas=J:\Census_Stuff\ACS2011_5yr\;
%let pathpdf=J:\Census_Stuff\ACS2011_5yr\SASRpts\;

%let obslimit=;
/* %let obslimit=obs=10000; /* For debugging */

libname CensSAS "&pathsas.SASData";
ods pdf file="&pathpdf.SAS21_Extract_&tablenum._Tract.pdf";

data Table_&tablenum._tract;
   set CensSAS.AllData_Seq&seqnum._tracts (&obslimit);
   if SUMLEV = '140';
   StCntyTract = STATE || COUNTY || TRACT;
   Est_tot_pop = var%eval(&firstvar+0);
   Est_native  = var%eval(&firstvar+1);
   Est_forborn = var%eval(&firstvar+2);
   MOE_tot_pop = mvar%eval(&firstvar+0);
   MOE_native  = mvar%eval(&firstvar+1);
   MOE_forborn = mvar%eval(&firstvar+2);
   DROP GEOCOMP LOGRECNO PLACE BLKGRP UR GEOID SEQUENCE
        var: mvar:;
   LABEL
    Est_tot_pop = 'Estimate total pop'
    Est_native  = 'Estimate native'
    Est_forborn = 'Estimate foreign born'
    MOE_tot_pop = 'Margin of error total pop'
    MOE_native  = 'Margin of error native'
    MOE_forborn = 'Margin of error foreign born'
    ;
run;

/* Sort and check for duplicates: */
proc sort data=Table_&tablenum._tract nodupkey out=CensSAS.Table_&tablenum._tract;
   by StCntyTract;
run;

/* Stats by state */
proc freq data=CensSAS.Table_&tablenum._tract;
   table STUSAB;
run;

/* Number of distinct values for each variable */
ods select nlevels;
proc freq data=CensSAS.Table_&tablenum._tract nlevels;
   tables STUSAB;
run;

ods pdf close;

