/* Extract ACS table B07001 (Residential Migration) for tracts (SUMLEV 140) */

options sysprintfont=("Courier New" 8) leftmargin=0.75in nocenter;

/* Specify ACS sequence number, the number of variables, and the table number: */
%let seqnum=016;  * The sequence number of file that contain the table you want (3 digits);
%let firstvar=7;  * Position of the first variable in the table;
%let tablenum=B07001_resmigr; * The ACS table number with descriptive suffix;
/* Example parameters seqnum=049, firstvar=219 for table C17002 (Ratio of Income to Poverty Level) */

/* Specify data path here for portability: */
%let pathsas=J:\Census_Stuff\ACS2011_5yr\;
%let pathpdf=J:\Census_Stuff\ACS2011_5yr\SASRpts\;

%let obslimit=;
/* %let obslimit=obs=10000; /* For debugging */

libname CensSAS "&pathsas.SASData";
ods pdf file="&pathpdf.SAS21_Extract_&tablenum._Tract.pdf";

data Table_&tablenum._tract;
   set CensSAS.AllData_Seq&seqnum._tracts (&obslimit);
   if SUMLEV = '140';
   StCntyTract = STATE || COUNTY || TRACT;
   Est_tot_pop        = var%eval(&firstvar+0);
   Est_same_house     = var%eval(&firstvar+16);
   Est_from_within_co = var%eval(&firstvar+32);
   Est_from_within_st = var%eval(&firstvar+48);
   Est_from_within_us = var%eval(&firstvar+64);
   Est_from_abroad    = var%eval(&firstvar+80);
   MOE_tot_pop        = mvar%eval(&firstvar+0);
   MOE_same_house     = mvar%eval(&firstvar+16);
   MOE_from_within_co = mvar%eval(&firstvar+32);
   MOE_from_within_st = mvar%eval(&firstvar+48);
   MOE_from_within_us = mvar%eval(&firstvar+64);
   MOE_from_abroad    = mvar%eval(&firstvar+80);
   DROP GEOCOMP LOGRECNO PLACE BLKGRP UR GEOID SEQUENCE
        var: mvar:;
   LABEL
    Est_tot_pop        = 'Estimate total pop'
    Est_same_house     = 'Estimate same house 1 year ago'
    Est_from_within_co = 'Estimate moved within same county'
    Est_from_within_st = 'Estimate moved from different county within same state'
    Est_from_within_us = 'Estimate moved from different state'
    Est_from_abroad    = 'Estimate moved from abroad'
    MOE_tot_pop        = 'Margin of error total pop'
    MOE_same_house     = 'Margin of error same house 1 year ago'
    MOE_from_within_co = 'Margin of error moved within same county'
    MOE_from_within_st = 'Margin of error moved from different county within same state'
    MOE_from_within_us = 'Margin of error moved from different state'
    MOE_from_abroad    = 'Margin of error moved from abroad'
    ;
run;

/* Sort and check for duplicates: */
proc sort data=Table_&tablenum._tract nodupkey out=CensSAS.Table_&tablenum._tract;
   by StCntyTract;
run;

/* Stats by state */
proc freq data=CensSAS.Table_&tablenum._tract;
   table STUSAB;
run;

/* Number of distinct values for each variable */
ods select nlevels;
proc freq data=CensSAS.Table_&tablenum._tract nlevels;
   tables STUSAB;
run;

ods pdf close;

