/* Extract ACS table B16002 (Linguistic Isolation) for tracts (SUMLEV 140) */

options sysprintfont=("Courier New" 8) leftmargin=0.75in nocenter;

/* Specify ACS sequence number, the number of variables, and the table number: */
%let seqnum=044;  * The sequence number of file that contain the table you want (3 digits);
%let firstvar=126;  * Position of the first variable in the table;
%let tablenum=B16002_lingiso; * The ACS table number with descriptive suffix;
/* Example parameters seqnum=049, firstvar=219 for table C17002 (Ratio of Income to Poverty Level) */

/* Specify data path here for portability: */
%let pathsas=J:\Census_Stuff\ACS2011_5yr\;
%let pathpdf=J:\Census_Stuff\ACS2011_5yr\SASRpts\;

%let obslimit=;
/* %let obslimit=obs=10000; /* For debugging */

libname CensSAS "&pathsas.SASData";
ods pdf file="&pathpdf.SAS21_Extract_&tablenum._Tract.pdf";

data Table_&tablenum._tract;
   set CensSAS.AllData_Seq&seqnum._tracts (&obslimit);
   if SUMLEV = '140';
   StCntyTract = STATE || COUNTY || TRACT;
   Est_tot_hh      = var%eval(&firstvar+0);
   Est_onlyEng     = var%eval(&firstvar+1);
   Est_Spa_tot     = var%eval(&firstvar+2);
   Est_Spa_lingiso = var%eval(&firstvar+3);
   Est_Spa_notliso = var%eval(&firstvar+4);
   Est_Ind_tot     = var%eval(&firstvar+5);
   Est_Ind_lingiso = var%eval(&firstvar+6);
   Est_Ind_notliso = var%eval(&firstvar+7);
   Est_API_tot     = var%eval(&firstvar+8);
   Est_API_lingiso = var%eval(&firstvar+9);
   Est_API_notliso = var%eval(&firstvar+10);
   Est_oth_tot     = var%eval(&firstvar+11);
   Est_oth_lingiso = var%eval(&firstvar+12);
   Est_oth_notliso = var%eval(&firstvar+13);
   MOE_tot_hh      = mvar%eval(&firstvar+0);
   MOE_onlyEng     = mvar%eval(&firstvar+1);
   MOE_Spa_tot     = mvar%eval(&firstvar+2);
   MOE_Spa_lingiso = mvar%eval(&firstvar+3);
   MOE_Spa_notliso = mvar%eval(&firstvar+4);
   MOE_Ind_tot     = mvar%eval(&firstvar+5);
   MOE_Ind_lingiso = mvar%eval(&firstvar+6);
   MOE_Ind_notliso = mvar%eval(&firstvar+7);
   MOE_API_tot     = mvar%eval(&firstvar+8);
   MOE_API_lingiso = mvar%eval(&firstvar+9);
   MOE_API_notliso = mvar%eval(&firstvar+10);
   MOE_oth_tot     = mvar%eval(&firstvar+11);
   MOE_oth_lingiso = mvar%eval(&firstvar+12);
   MOE_oth_notliso = mvar%eval(&firstvar+13);
   DROP GEOCOMP LOGRECNO PLACE BLKGRP UR GEOID SEQUENCE
        var: mvar:;
   LABEL
    Est_tot_hh      = 'Estimate total households'
    Est_onlyEng     = 'Estimate only English'
    Est_Spa_tot     = 'Estimate Spanish total'
    Est_Spa_lingiso = 'Estimate Spanish linguistically isolated'
    Est_Spa_notliso = 'Estimate Spanish not linguistically isolated'
    Est_Ind_tot     = 'Estimate IndoEur total'
    Est_Ind_lingiso = 'Estimate IndoEur linguistically isolated'
    Est_Ind_notliso = 'Estimate IndoEur not linguistically isolated'
    Est_API_tot     = 'Estimate AsianPI total'
    Est_API_lingiso = 'Estimate AsianPI linguistically isolated'
    Est_API_notliso = 'Estimate AsianPI not linguistically isolated'
    Est_oth_tot     = 'Estimate othrLan total'
    Est_oth_lingiso = 'Estimate othrLan linguistically isolated'
    Est_oth_notliso = 'Estimate othrLan not linguistically isolated'
    MOE_tot_hh      = 'Margin of error total households'
    MOE_onlyEng     = 'Margin of error only English'
    MOE_Spa_tot     = 'Margin of error Spanish total'
    MOE_Spa_lingiso = 'Margin of error Spanish linguistically isolated'
    MOE_Spa_notliso = 'Margin of error Spanish not linguistically isolated'
    MOE_Ind_tot     = 'Margin of error IndoEur total'
    MOE_Ind_lingiso = 'Margin of error IndoEur linguistically isolated'
    MOE_Ind_notliso = 'Margin of error IndoEur not linguistically isolated'
    MOE_API_tot     = 'Margin of error AsianPI total'
    MOE_API_lingiso = 'Margin of error AsianPI linguistically isolated'
    MOE_API_notliso = 'Margin of error AsianPI not linguistically isolated'
    MOE_oth_tot     = 'Margin of error othrLan total'
    MOE_oth_lingiso = 'Margin of error othrLan linguistically isolated'
    MOE_oth_notliso = 'Margin of error othrLan not linguistically isolated'
    ;
run;

/* Sort and check for duplicates: */
proc sort data=Table_&tablenum._tract nodupkey out=CensSAS.Table_&tablenum._tract;
   by StCntyTract;
run;

/* Stats by state */
proc freq data=CensSAS.Table_&tablenum._tract;
   table STUSAB;
run;

/* Number of distinct values for each variable */
ods select nlevels;
proc freq data=CensSAS.Table_&tablenum._tract nlevels;
   tables STUSAB;
run;

ods pdf close;

