/* Extract ACS table C17002 (Ratio of Income to Poverty Level) for tracts (SUMLEV 140) */

options sysprintfont=("Courier New" 8) leftmargin=0.75in nocenter;

/* Specify ACS sequence number, the number of variables, and the table number: */
%let seqnum=049;  * The sequence number of file that contain the table you want (3 digits);
%let firstvar=219;  * Position of the first variable in the table;
%let tablenum=C17002_povrel; * The ACS table number with descriptive suffix;
/* Example parameters seqnum=049, firstvar=219 for table C17002 (Ratio of Income to Poverty Level) */

/* Specify data path here for portability: */
%let pathsas=J:\Census_Stuff\ACS2011_5yr\;
%let pathpdf=J:\Census_Stuff\ACS2011_5yr\SASRpts\;

%let obslimit=;
/* %let obslimit=obs=10000; /* For debugging */

libname CensSAS "&pathsas.SASData";
ods pdf file="&pathpdf.SAS21_Extract_&tablenum._Tract.pdf";

data Table_&tablenum._tract;
   set CensSAS.AllData_Seq&seqnum._tracts (&obslimit);
   if SUMLEV = '140';
   StCntyTract = STATE || COUNTY || TRACT;
   Est_tot_pop  = var%eval(&firstvar+0);
   Est_under50  = var%eval(&firstvar+1);
   Est_50to99   = var%eval(&firstvar+2);
   Est_100to124 = var%eval(&firstvar+3);
   Est_125to149 = var%eval(&firstvar+4);
   Est_150to184 = var%eval(&firstvar+5);
   Est_185to199 = var%eval(&firstvar+6);
   Est_200over  = var%eval(&firstvar+7);
   MOE_tot_pop  = mvar%eval(&firstvar+0);
   MOE_under50  = mvar%eval(&firstvar+1);
   MOE_50to99   = mvar%eval(&firstvar+2);
   MOE_100to124 = mvar%eval(&firstvar+3);
   MOE_125to149 = mvar%eval(&firstvar+4);
   MOE_150to184 = mvar%eval(&firstvar+5);
   MOE_185to199 = mvar%eval(&firstvar+6);
   MOE_200over  = mvar%eval(&firstvar+7);
   DROP GEOCOMP LOGRECNO PLACE BLKGRP UR GEOID SEQUENCE
        var: mvar:;
   LABEL
    Est_tot_pop  = 'Estimate total pop'
    Est_under50  = 'Estimate under 50%'
    Est_50to99   = 'Estimate 50% to 99%'
    Est_100to124 = 'Estimate 100% to 124%'
    Est_125to149 = 'Estimate 125% to 149%'
    Est_150to184 = 'Estimate 150% to 184%'
    Est_185to199 = 'Estimate 185% to 199%'
    Est_200over  = 'Estimate over 200%'
    MOE_tot_pop  = 'Margin of error total pop'
    MOE_under50  = 'Margin of error under 50%'
    MOE_50to99   = 'Margin of error 50% to 99%'
    MOE_100to124 = 'Margin of error 100% to 124%'
    MOE_125to149 = 'Margin of error 125% to 149%'
    MOE_150to184 = 'Margin of error 150% to 184%'
    MOE_185to199 = 'Margin of error 185% to 199%'
    MOE_200over  = 'Margin of error over 200%'
    ;
run;

/* Sort and check for duplicates: */
proc sort data=Table_&tablenum._tract nodupkey out=CensSAS.Table_&tablenum._tract;
   by StCntyTract;
run;

/* Stats by state */
proc freq data=CensSAS.Table_&tablenum._tract;
   table STUSAB;
run;

/* Number of distinct values for each variable */
ods select nlevels;
proc freq data=CensSAS.Table_&tablenum._tract nlevels;
   tables STUSAB;
run;

ods pdf close;

