/* Load ACS subject table S1501 (Educ Attainment) for tracts (SUMLEV 140) */

options sysprintfont=("Courier New" 8) leftmargin=0.75in nocenter;

/* Specify the ACS table number and suffix for folder and file names: */
%let tablenum=S1501; * The ACS table number;
%let tablesuf=educ; * The ACS table descriptive suffix;
%let first=2; * The first data line - may vary by table and year-to-year;

/* Specify data path here for portability: */
%let pathin=J:\Census_Stuff\ACS2011_5yr\Downloaded_SubjectTable_Data\;
%let pathsas=J:\Census_Stuff\ACS2011_5yr\;
%let pathpdf=J:\Census_Stuff\ACS2011_5yr\SASRpts\;
%let acsendyear=11; /* 2011 */

%let obslimit=;
/* %let obslimit=obs=10000; /* For debugging */

libname CensSAS "&pathsas.SASData";
%let table=&tablenum._&tablesuf.;
ods pdf file="&pathpdf.SAS22_Load_&table._Tract.pdf";

/* options mprint mlogic symbolgen; /* for macro debugging */

/* Read in subject table for states A-M */
data tempSubj_A_M;
   infile "&pathin.\ACS_&acsendyear._5YR_&tablenum._with_ann_A_M.csv"
      LRECL = 32000 delimiter = ',' dsd firstobs=&first. &obslimit.;
   length
      GEO_ID      $20
      StCntyTract $11
      STATE       $2
      COUNTY      $3
      GEO_NAME    $200
      C0-C85      $12
      ;
   input
      GEO_ID       $
      StCntyTract  $
      GEO_NAME     $
      C0-C85       $
      ;
   STATE = substr(StCntyTract,1,2);
   COUNTY = substr(StCntyTract,3,3);
   Est_totpop_educsubj  = input(c30, ?? comma10.);
   MOE_totpop_educsubj  = input(c31, ?? comma10.);
   Pctsubj_highsch      = input(c78, ?? comma10.);
   Pctsubj_highsch_MOE  = input(c79, ?? comma10.);
   if Pctsubj_highsch   < 0 then Pctsubj_highsch    = .;
   if (Pctsubj_highsch ^= .) and (Pctsubj_highsch ^= 0) then
      Pctsubj_highsch_CV = (Pctsubj_highsch_MOE / 1.645) * 100 / Pctsubj_highsch;
   else Pctsubj_highsch_CV = .;
   if Pctsubj_highsch ^= . then do;
      Pctsubj_notHS     = 100 - Pctsubj_highsch;
      Pctsubj_notHS_MOE = Pctsubj_highsch_MOE;
      end;
   if (Pctsubj_notHS ^= .) and (Pctsubj_notHS ^= 0) then
      Pctsubj_notHS_CV = (Pctsubj_notHS_MOE / 1.645) * 100 / Pctsubj_notHS;
   else Pctsubj_notHS_CV = .;
   Pctsubj_college      = input(c84, ?? comma10.);
   Pctsubj_college_MOE  = input(c85, ?? comma10.);
   if Pctsubj_college   < 0 then Pctsubj_college    = .;
   if (Pctsubj_college ^= .) and (Pctsubj_college ^= 0) then
      Pctsubj_college_CV = (Pctsubj_college_MOE / 1.645) * 100 / Pctsubj_college;
   else Pctsubj_college_CV = .;
   LABEL    GEO_ID       = 'Geography Identifier'
            StCntyTract  = 'Census Tract 11-digit FIPS Code'
            GEO_NAME     = 'Area Name'
            Pctsubj_highsch     = 'Percent high school (from subj table)'
            Pctsubj_highsch_MOE = 'Percent high school MOE (from subj table)'
            Pctsubj_highsch_CV  = 'Percent high school CV (from subj table)'
            Pctsubj_notHS       = 'Percent less than HS (from subj table)'
            Pctsubj_notHS_MOE   = 'Percent less than HS MOE (from subj table)'
            Pctsubj_notHS_CV    = 'Percent less than HS CV (from subj table)'
            Pctsubj_college     = 'Percent college (from subj table)'
            Pctsubj_college_MOE = 'Percent college MOE (from subj table)'
            Pctsubj_college_CV  = 'Percent college CV (from subj table)'
            ;
   FORMAT   Pctsubj_highsch     5.1
            Pctsubj_highsch_MOE 5.1
            Pctsubj_highsch_CV  5.1
            Pctsubj_notHS       5.1
            Pctsubj_notHS_MOE   5.1
            Pctsubj_notHS_CV    5.1
            Pctsubj_college     5.1
            Pctsubj_college_MOE 5.1
            Pctsubj_college_CV  5.1
            ;
   drop GEO_ID C0-C85;
run;
/* Read in subject table for states N-W */
data tempSubj_N_W;
   infile "&pathin.\ACS_&acsendyear._5YR_&tablenum._with_ann_N_W.csv"
      LRECL = 32000 delimiter = ',' dsd firstobs=&first. &obslimit.;
   length
      GEO_ID      $20
      StCntyTract $11
      STATE       $2
      COUNTY      $3
      GEO_NAME    $200
      C0-C85      $12
      ;
   input
      GEO_ID       $
      StCntyTract  $
      GEO_NAME     $
      C0-C85       $
      ;
   STATE = substr(StCntyTract,1,2);
   COUNTY = substr(StCntyTract,3,3);
   Est_totpop_educsubj  = input(c30, ?? comma10.);
   MOE_totpop_educsubj  = input(c31, ?? comma10.);
   Pctsubj_highsch      = input(c78, ?? comma10.);
   Pctsubj_highsch_MOE  = input(c79, ?? comma10.);
   if Pctsubj_highsch   < 0 then Pctsubj_highsch    = .;
   if (Pctsubj_highsch ^= .) and (Pctsubj_highsch ^= 0) then
      Pctsubj_highsch_CV = (Pctsubj_highsch_MOE / 1.645) * 100 / Pctsubj_highsch;
   else Pctsubj_highsch_CV = .;
   if Pctsubj_highsch ^= . then do;
      Pctsubj_notHS     = 100 - Pctsubj_highsch;
      Pctsubj_notHS_MOE = Pctsubj_highsch_MOE;
      end;
   if (Pctsubj_notHS ^= .) and (Pctsubj_notHS ^= 0) then
      Pctsubj_notHS_CV = (Pctsubj_notHS_MOE / 1.645) * 100 / Pctsubj_notHS;
   else Pctsubj_notHS_CV = .;
   Pctsubj_college      = input(c84, ?? comma10.);
   Pctsubj_college_MOE  = input(c85, ?? comma10.);
   if Pctsubj_college   < 0 then Pctsubj_college    = .;
   if (Pctsubj_college ^= .) and (Pctsubj_college ^= 0) then
      Pctsubj_college_CV = (Pctsubj_college_MOE / 1.645) * 100 / Pctsubj_college;
   else Pctsubj_college_CV = .;
   LABEL    GEO_ID       = 'Geography Identifier'
            StCntyTract  = 'Census Tract 11-digit FIPS Code'
            GEO_NAME     = 'Area Name'
            Pctsubj_highsch     = 'Percent high school (from subj table)'
            Pctsubj_highsch_MOE = 'Percent high school MOE (from subj table)'
            Pctsubj_highsch_CV  = 'Percent high school CV (from subj table)'
            Pctsubj_notHS       = 'Percent less than HS (from subj table)'
            Pctsubj_notHS_MOE   = 'Percent less than HS MOE (from subj table)'
            Pctsubj_notHS_CV    = 'Percent less than HS CV (from subj table)'
            Pctsubj_college     = 'Percent college (from subj table)'
            Pctsubj_college_MOE = 'Percent college MOE (from subj table)'
            Pctsubj_college_CV  = 'Percent college CV (from subj table)'
            ;
   FORMAT   Pctsubj_highsch     5.1
            Pctsubj_highsch_MOE 5.1
            Pctsubj_highsch_CV  5.1
            Pctsubj_notHS       5.1
            Pctsubj_notHS_MOE   5.1
            Pctsubj_notHS_CV    5.1
            Pctsubj_college     5.1
            Pctsubj_college_MOE 5.1
            Pctsubj_college_CV  5.1
            ;
   drop GEO_ID C0-C85;
run;
/* Combine the two pieces */
data Table_&table._tract;
    set tempSubj_A_M
        tempSubj_N_W;
run;

/* Sort and check for duplicates: */
proc sort data=Table_&table._tract nodupkey out=CensSAS.Table_&table._tract;
   by StCntyTract;
run;

/* Stats by state */
proc freq data=CensSAS.Table_&table._tract;
   table STATE;
run;

/* Stats for all percentages (not weighted) */
proc means data=CensSAS.Table_&table._tract NOLABELS N MEAN STD MIN MAX ;
   var Pctsubj_highsch     Pctsubj_notHS     Pctsubj_college
       Pctsubj_highsch_MOE Pctsubj_notHS_MOE Pctsubj_college_MOE;
run;

/* Horizontal bar chart for percentages */
proc chart data=CensSAS.Table_&table._tract /* noprint */ ;
   hbar Pctsubj_highsch / missing midpoints = 0 to 100 by 5;
   hbar Pctsubj_notHS   / missing midpoints = 0 to 100 by 5;
   hbar Pctsubj_college / missing midpoints = 0 to 100 by 5;
run;

/* Number of distinct values for each variable */
ods select nlevels;
proc freq data=CensSAS.Table_&table._tract nlevels;
   table STATE;
run;

ods pdf close;
