/* Load ACS subject table S1602 (Ling Isolation) for tracts (SUMLEV 140) */

options sysprintfont=("Courier New" 8) leftmargin=0.75in nocenter;

/* Specify the ACS table number and suffix for folder and file names: */
%let tablenum=S1602; * The ACS table number;
%let tablesuf=lingiso; * The ACS table descriptive suffix;
%let first=2; * The first data line - may vary by table and year-to-year;

/* Specify data path here for portability: */
%let pathin=J:\Census_Stuff\ACS2011_5yr\Downloaded_SubjectTable_Data\;
%let pathsas=J:\Census_Stuff\ACS2011_5yr\;
%let pathpdf=J:\Census_Stuff\ACS2011_5yr\SASRpts\;
%let acsendyear=11; /* 2011 */

%let obslimit=;
/* %let obslimit=obs=10000; /* For debugging */

libname CensSAS "&pathsas.SASData";
%let table=&tablenum._&tablesuf.;
ods pdf file="&pathpdf.SAS22_Load_&table._Tract.pdf";

/* options mprint mlogic symbolgen; /* for macro debugging */

/* Read in subject table for states A-M */
data tempSubj_A_M;
   infile "&pathin.\ACS_&acsendyear._5YR_&tablenum._with_ann_A_M.csv"
      LRECL = 32000 delimiter = ',' dsd firstobs=&first. &obslimit.;
   length
      GEO_ID      $20
      StCntyTract $11
      STATE       $2
      COUNTY      $3
      GEO_NAME    $200
      C0-C1       $12
      ;
   input
      GEO_ID       $
      StCntyTract  $
      GEO_NAME     $
      C0-C1        $
      ;
   STATE = substr(StCntyTract,1,2);
   COUNTY = substr(StCntyTract,3,3);
   Pctsubj_lingiso      = input(c0, ?? comma10.);
   Pctsubj_lingiso_MOE  = input(c1, ?? comma10.);
   if Pctsubj_lingiso   < 0 then Pctsubj_lingiso    = .;
   if (Pctsubj_lingiso ^= .) and (Pctsubj_lingiso ^= 0) then
      Pctsubj_lingiso_CV = (Pctsubj_lingiso_MOE / 1.645) * 100 / Pctsubj_lingiso;
   else Pctsubj_lingiso_CV = .;
   LABEL    GEO_ID       = 'Geography Identifier'
            StCntyTract  = 'Census Tract 11-digit FIPS Code'
            GEO_NAME     = 'Area Name'
            Pctsubj_lingiso     = 'Percent linguistically isolated households (from subj table)'
            Pctsubj_lingiso_MOE = 'Percent linguistically isolated households MOE (from subj table)'
            Pctsubj_lingiso_CV  = 'Percent linguistically isolated households CV (from subj table)'
            ;
   FORMAT   Pctsubj_lingiso     5.1
            Pctsubj_lingiso_MOE 5.1
            Pctsubj_lingiso_CV  5.1
            ;
   drop GEO_ID C0-C1;
run;
/* Read in subject table for states N-W */
data tempSubj_N_W;
   infile "&pathin.\ACS_&acsendyear._5YR_&tablenum._with_ann_N_W.csv"
      LRECL = 32000 delimiter = ',' dsd firstobs=&first. &obslimit.;
   length
      GEO_ID      $20
      StCntyTract $11
      STATE       $2
      COUNTY      $3
      GEO_NAME    $200
      C0-C1       $12
      ;
   input
      GEO_ID       $
      StCntyTract  $
      GEO_NAME     $
      C0-C1        $
      ;
   STATE = substr(StCntyTract,1,2);
   COUNTY = substr(StCntyTract,3,3);
   Pctsubj_lingiso      = input(c0, ?? comma10.);
   Pctsubj_lingiso_MOE  = input(c1, ?? comma10.);
   if Pctsubj_lingiso   < 0 then Pctsubj_lingiso    = .;
   if (Pctsubj_lingiso ^= .) and (Pctsubj_lingiso ^= 0) then
      Pctsubj_lingiso_CV = (Pctsubj_lingiso_MOE / 1.645) * 100 / Pctsubj_lingiso;
   else Pctsubj_lingiso_CV = .;
   LABEL    GEO_ID       = 'Geography Identifier'
            StCntyTract  = 'Census Tract 11-digit FIPS Code'
            GEO_NAME     = 'Area Name'
            Pctsubj_lingiso     = 'Percent linguistically isolated households (from subj table)'
            Pctsubj_lingiso_MOE = 'Percent linguistically isolated households MOE (from subj table)'
            Pctsubj_lingiso_CV  = 'Percent linguistically isolated households CV (from subj table)'
            ;
   FORMAT   Pctsubj_lingiso     5.1
            Pctsubj_lingiso_MOE 5.1
            Pctsubj_lingiso_CV  5.1
            ;
   drop GEO_ID C0-C1;
run;
/* Combine the two pieces */
data Table_&table._tract;
    set tempSubj_A_M
        tempSubj_N_W;
run;

/* Sort and check for duplicates: */
proc sort data=Table_&table._tract nodupkey out=CensSAS.Table_&table._tract;
   by StCntyTract;
run;

/* Stats by state */
proc freq data=CensSAS.Table_&table._tract;
   table STATE;
run;

/* Stats for all percentages (not weighted) */
proc means data=CensSAS.Table_&table._tract NOLABELS N MEAN STD MIN MAX ;
   var Pctsubj_lingiso
       Pctsubj_lingiso_MOE;
run;

/* Horizontal bar chart for percentages */
proc chart data=CensSAS.Table_&table._tract /* noprint */ ;
   hbar Pctsubj_lingiso / missing midpoints = 0 to 100 by 5;
run;

/* Number of distinct values for each variable */
ods select nlevels;
proc freq data=CensSAS.Table_&table._tract nlevels;
   table STATE;
run;

ods pdf close;
