/* Stats for calculated tract attribute data (percents and their MOEs) */

options sysprintfont=("Courier New" 8) leftmargin=0.75in nocenter;

/* Specify data path here for portability: */
%let pathsas=J:\Census_Stuff\ACS2011_5yr\;
%let pathpdf=J:\Census_Stuff\ACS2011_5yr\SASRpts\;

%let obslimit=;
/* %let obslimit=obs=10000; /* For debugging */

libname CensSAS "&pathsas.SASData";
ods pdf file="&pathpdf.SAS41_Stats_Tract_Attributes.pdf" uniform ;

/* Basic descriptive stats for calculated percentages and MOEs */
title 'Descriptive stats: calculated percentages and MOEs (not population-weighted)';
proc means data=CensSAS.Tract_Attributes_clean nolabels n min mean max stddev cv nmiss ;
   var
    Pct_sampled
    Pct_nonwhite        Pct_nonwhite_MOE
    Pct_Hispanic        Pct_Hispanic_MOE
    Pct_minority        Pct_minority_MOE
    Pct_forborn         Pct_forborn_MOE
    Pctsubj_highsch     Pctsubj_highsch_MOE
    Pctsubj_notHS       Pctsubj_notHS_MOE
    Pctsubj_college     Pctsubj_college_MOE
    Pctsubj_lingiso     Pctsubj_lingiso_MOE
    Pct_noEngl          Pct_noEngl_MOE
    Pct_be150pov        Pct_be150pov_MOE
    Pctsubj_belowpov    Pctsubj_belowpov_MOE
    Pctsubj_unemploy    Pctsubj_unemploy_MOE
    Pct_same_house      Pct_same_house_MOE
    Pct_from_within_co  Pct_from_within_co_MOE
    Pct_from_within_st  Pct_from_within_st_MOE
    Pct_from_within_us  Pct_from_within_us_MOE
    ;
run;

/* Basic descriptive stats for calculated percentages and MOEs */
title 'Descriptive stats: calculated percentages and MOEs (weighted by tract population)';
proc means data=CensSAS.Tract_Attributes_clean nolabels n min mean max nmiss ;
   var
    Pct_sampled
    Pct_nonwhite        Pct_nonwhite_MOE
    Pct_Hispanic        Pct_Hispanic_MOE
    Pct_minority        Pct_minority_MOE
    Pct_forborn         Pct_forborn_MOE
    Pctsubj_highsch     Pctsubj_highsch_MOE
    Pctsubj_notHS       Pctsubj_notHS_MOE
    Pctsubj_college     Pctsubj_college_MOE
    Pctsubj_lingiso     Pctsubj_lingiso_MOE
    Pct_noEngl          Pct_noEngl_MOE
    Pct_be150pov        Pct_be150pov_MOE
    Pctsubj_belowpov    Pctsubj_belowpov_MOE
    Pctsubj_unemploy    Pctsubj_unemploy_MOE
    Pct_same_house      Pct_same_house_MOE
    Pct_from_within_co  Pct_from_within_co_MOE
    Pct_from_within_st  Pct_from_within_st_MOE
    Pct_from_within_us  Pct_from_within_us_MOE
    / weight=Totpop;
run;

/* Stats of calculated percentages */
title 'Univariate stats: calculated percentages';
proc univariate data=CensSAS.Tract_Attributes_clean /* noprint */ ;
   var
      Pct_sampled
      Pct_nonwhite
      Pct_Hispanic
      Pct_minority
      Pct_forborn
      Pctsubj_highsch
      Pctsubj_notHS
      Pctsubj_college
      Pctsubj_lingiso
      Pct_noEngl
      Pct_be150pov
      Pctsubj_belowpov
      Pctsubj_unemploy
      Pct_same_house
      Pct_from_within_co
      Pct_from_within_st
      Pct_from_within_us
      ;
run;

/* Stats of calculated MOEs */
title 'Univariate stats: calculated MOEs';
proc univariate data=CensSAS.Tract_Attributes_clean /* noprint */ ;
   var
      Pct_nonwhite_MOE
      Pct_Hispanic_MOE
      Pct_minority_MOE
      Pct_forborn_MOE
      Pctsubj_highsch_MOE
      Pctsubj_notHS_MOE
      Pctsubj_college_MOE
      Pctsubj_lingiso_MOE
      Pct_noEngl_MOE
      Pct_be150pov_MOE
      Pctsubj_belowpov_MOE
      Pctsubj_unemploy_MOE
      Pct_same_house_MOE
      Pct_from_within_co_MOE
      Pct_from_within_st_MOE
      Pct_from_within_us_MOE
      ;
run;

/* Histograms of calculated percentages */
title 'Histograms: calculated percentages';
proc univariate data=CensSAS.Tract_Attributes_clean noprint ;
   histogram
      Pct_sampled
      Pct_nonwhite
      Pct_Hispanic
      Pct_minority
      Pct_forborn
      Pctsubj_highsch
      Pctsubj_notHS
      Pctsubj_college
      Pctsubj_lingiso
      Pct_noEngl
      Pct_be150pov
      Pctsubj_belowpov
      Pctsubj_unemploy
      Pct_same_house
      Pct_from_within_co
      Pct_from_within_st
      Pct_from_within_us
      ;
run;

/* Histograms of calculated MOEs */
title 'Histograms: calculated MOEs';
proc univariate data=CensSAS.Tract_Attributes_clean noprint;
   histogram
      Pct_nonwhite_MOE
      Pct_Hispanic_MOE
      Pct_minority_MOE
      Pct_forborn_MOE
      Pctsubj_highsch_MOE
      Pctsubj_notHS_MOE
      Pctsubj_college_MOE
      Pctsubj_lingiso_MOE
      Pct_noEngl_MOE
      Pct_be150pov_MOE
      Pctsubj_belowpov_MOE
      Pctsubj_unemploy_MOE
      Pct_same_house_MOE
      Pct_from_within_co_MOE
      Pct_from_within_st_MOE
      Pct_from_within_us_MOE
      ;
run;

title 'Correlations between the measures and their MOEs';
/* Correlations between the measures and their MOEs: */
proc corr data=CensSAS.Tract_Attributes_clean (&obslimit.) /* noprob nosimple */
    outp=corrout noprint;
    var
      Pct_nonwhite
      Pct_Hispanic
      Pct_minority
      Pct_forborn
      Pctsubj_highsch
      Pctsubj_notHS
      Pctsubj_college
      Pctsubj_lingiso
      Pct_noEngl
      Pct_be150pov
      Pctsubj_belowpov
      Pctsubj_unemploy
      Pct_same_house
      Pct_from_within_co
      Pct_from_within_st
      Pct_from_within_us
      ;
    with
      Pct_nonwhite_MOE
      Pct_Hispanic_MOE
      Pct_minority_MOE
      Pct_forborn_MOE
      Pctsubj_highsch_MOE
      Pctsubj_notHS_MOE
      Pctsubj_college_MOE
      Pctsubj_lingiso_MOE
      Pct_noEngl_MOE
      Pct_be150pov_MOE
      Pctsubj_belowpov_MOE
      Pctsubj_unemploy_MOE
      Pct_same_house_MOE
      Pct_from_within_co_MOE
      Pct_from_within_st_MOE
      Pct_from_within_us_MOE
      ;
run;
data corrout_MOE;
    set corrout;
    length varEst varMOE $30;
    if _TYPE_ = 'CORR';
    if _NAME_ = 'Pct_nonwhite_MOE' then do;
        varEst =  'Pct_nonwhite';     varMOE='Pct_nonwhite_MOE';     corrMOE=Pct_nonwhite; end;
    if _NAME_ = 'Pct_Hispanic_MOE' then do;
        varEst =  'Pct_Hispanic';     varMOE='Pct_Hispanic_MOE';     corrMOE=Pct_Hispanic; end;
    if _NAME_ = 'Pct_minority_MOE' then do;
        varEst =  'Pct_minority';     varMOE='Pct_minority_MOE';     corrMOE=Pct_minority; end;
    if _NAME_ = 'Pct_forborn_MOE' then do;
        varEst =  'Pct_forborn';      varMOE='Pct_forborn_MOE';      corrMOE=Pct_forborn; end;
    if _NAME_ = 'Pctsubj_highsch_MOE' then do;
        varEst =  'Pctsubj_highsch';  varMOE='Pctsubj_highsch_MOE';  corrMOE=Pctsubj_highsch; end;
    if _NAME_ = 'Pctsubj_notHS_MOE' then do;
        varEst =  'Pctsubj_notHS';    varMOE='Pctsubj_notHS_MOE';    corrMOE=Pctsubj_notHS; end;
    if _NAME_ = 'Pctsubj_college_MOE' then do;
        varEst =  'Pctsubj_college';  varMOE='Pctsubj_college_MOE';  corrMOE=Pctsubj_college; end;
    if _NAME_ = 'Pctsubj_lingiso_MOE' then do;
        varEst =  'Pctsubj_lingiso';  varMOE='Pctsubj_lingiso_MOE';  corrMOE=Pctsubj_lingiso; end;
    if _NAME_ = 'Pct_noEngl_MOE' then do;
        varEst =  'Pct_noEngl';       varMOE='Pct_noEngl_MOE';       corrMOE=Pct_noEngl; end;
    if _NAME_ = 'Pct_be150pov_MOE' then do;
        varEst =  'Pct_be150pov';     varMOE='Pct_be150pov_MOE';     corrMOE=Pct_be150pov; end;
    if _NAME_ = 'Pctsubj_belowpov_MOE' then do;
        varEst =  'Pctsubj_belowpov'; varMOE='Pctsubj_belowpov_MOE'; corrMOE=Pctsubj_belowpov; end;
    if _NAME_ = 'Pctsubj_unemploy_MOE' then do;
        varEst =  'Pctsubj_unemploy'; varMOE='Pctsubj_unemploy_MOE'; corrMOE=Pctsubj_unemploy; end;
    if _NAME_ = 'Pct_same_house_MOE' then do;
        varEst =  'Pct_same_house';   varMOE='Pct_same_house_MOE';   corrMOE=Pct_same_house; end;
    if _NAME_ = 'Pct_from_within_co_MOE' then do;
        varEst =  'Pct_from_within_co'; varMOE='Pct_from_within_co_MOE'; corrMOE=Pct_from_within_co; end;
    if _NAME_ = 'Pct_from_within_st_MOE' then do;
        varEst =  'Pct_from_within_st'; varMOE='Pct_from_within_st_MOE'; corrMOE=Pct_from_within_st; end;
    if _NAME_ = 'Pct_from_within_us_MOE' then do;
        varEst =  'Pct_from_within_us'; varMOE='Pct_from_within_us_MOE'; corrMOE=Pct_from_within_us; end;
    keep varEst varMOE corrMOE;
run;
proc print noobs;
run;

options nolabel;

title 'Scatterplots between the measures and their MOEs';
/* Scatterplots between the measures and their MOEs */
ods graphics on / AntiAlias=OFF ; /* For sgscatter procedure */
proc sgscatter data=CensSAS.Tract_Attributes_clean;
  plot  Pct_nonwhite        * Pct_nonwhite_MOE
        Pct_Hispanic        * Pct_Hispanic_MOE
        Pct_minority        * Pct_minority_MOE
        Pct_forborn         * Pct_forborn_MOE;
run;
proc sgscatter data=CensSAS.Tract_Attributes_clean;
  plot  Pctsubj_highsch     * Pctsubj_highsch_MOE
        Pctsubj_notHS       * Pctsubj_notHS_MOE;
run;
proc sgscatter data=CensSAS.Tract_Attributes_clean;
  plot  Pctsubj_college     * Pctsubj_college_MOE
        Pctsubj_lingiso     * Pctsubj_lingiso_MOE
        Pct_noEngl          * Pct_noEngl_MOE;
run;
proc sgscatter data=CensSAS.Tract_Attributes_clean;
  plot  Pct_be150pov        * Pct_be150pov_MOE
        Pctsubj_belowpov    * Pctsubj_belowpov_MOE
        Pctsubj_unemploy    * Pctsubj_unemploy_MOE;
run;
proc sgscatter data=CensSAS.Tract_Attributes_clean;
  plot  Pct_same_house      * Pct_same_house_MOE
        Pct_from_within_co  * Pct_from_within_co_MOE
        Pct_from_within_st  * Pct_from_within_st_MOE
        Pct_from_within_us  * Pct_from_within_us_MOE;
run;

title 'Correlations between MOEs';
/* Correlation matrix between MOEs: */
proc corr data=CensSAS.Tract_Attributes_clean noprob nosimple
    outp=corrout noprint
    /* plots=matrix */ ;
    var
      Totpop
      Totpop_MOE
      Popsamps
      Pct_sampled
      Pct_nonwhite_MOE
      Pct_Hispanic_MOE
      Pct_minority_MOE
      Pctsubj_highsch_MOE
      Pctsubj_notHS_MOE
      Pctsubj_college_MOE
      Pct_forborn_MOE
      Pctsubj_lingiso_MOE
      Pct_noEngl_MOE
      Pctsubj_belowpov_MOE
      Pctsubj_unemploy_MOE
      Pct_same_house_MOE
      Pct_from_within_co_MOE
      Pct_from_within_st_MOE
      Pct_from_within_us_MOE
      ;
run;
proc print data=corrout split='_';
    id _NAME_;
    var _TYPE_
      Totpop
      Totpop_MOE
      Popsamps
      Pct_sampled
      Pct_nonwhite_MOE
      Pct_Hispanic_MOE
      Pct_minority_MOE
      ;
run;
proc print data=corrout split='_';
    id _NAME_;
    var _TYPE_
      Pctsubj_highsch_MOE
      Pctsubj_notHS_MOE
      Pctsubj_college_MOE
      ;
run;
proc print data=corrout split='_';
    id _NAME_;
    var _TYPE_
      Pct_forborn_MOE
      Pctsubj_lingiso_MOE
      Pct_noEngl_MOE
      Pctsubj_belowpov_MOE
      Pctsubj_unemploy_MOE
      ;
run;
proc print data=corrout split='_';
    id _NAME_;
    var _TYPE_
      Pct_same_house_MOE
      Pct_from_within_co_MOE
      Pct_from_within_st_MOE
      Pct_from_within_us_MOE
      ;
run;

ods pdf close;

