/* Stats by state for calculated tract attribute data (percents and their MOEs) */

options sysprintfont=("Courier New" 8) leftmargin=0.75in nocenter;

/* Specify data path here for portability: */
%let pathsas=J:\Census_Stuff\ACS2011_5yr\;
%let pathpdf=J:\Census_Stuff\ACS2011_5yr\SASRpts\;

%let obslimit=;
/* %let obslimit=obs=10000; /* For debugging */

libname CensSAS "&pathsas.SASData";
ods pdf file="&pathpdf.SAS42_StatsByState_Tract_Attributes.pdf" uniform;

/* Basic descriptive stats for calculated percentages and MOEs */
title 'Descriptive stats: calculated percentages and MOEs (weighted by tract population)';
proc means data=CensSAS.Tract_Attributes_clean nolabels n min mean max nmiss;
    by STUSAB;
   var
    Pct_sampled
    Pct_nonwhite        Pct_nonwhite_MOE
    Pct_Hispanic        Pct_Hispanic_MOE
    Pct_minority        Pct_minority_MOE
    Pct_forborn         Pct_forborn_MOE
    Pctsubj_highsch     Pctsubj_highsch_MOE
    Pctsubj_notHS       Pctsubj_notHS_MOE
    Pctsubj_college     Pctsubj_college_MOE
    Pctsubj_lingiso     Pctsubj_lingiso_MOE
    Pct_noEngl          Pct_noEngl_MOE
    Pct_be150pov        Pct_be150pov_MOE
    Pctsubj_belowpov    Pctsubj_belowpov_MOE
    Pctsubj_unemploy    Pctsubj_unemploy_MOE
    Pct_same_house      Pct_same_house_MOE
    Pct_from_within_co  Pct_from_within_co_MOE
    Pct_from_within_st  Pct_from_within_st_MOE
    Pct_from_within_us  Pct_from_within_us_MOE
    / weight=Totpop;
run;

/* Simpler descriptive stats for MOEs for Excel */
title 'N, mean, and StdDev for MOEs - all US (weighted by tract population)';
proc means data=CensSAS.Tract_Attributes_clean nolabels n mean ;
   var
    Pct_sampled
    Pct_nonwhite_MOE
    Pct_Hispanic_MOE
    Pct_minority_MOE
    Pct_forborn_MOE
    Pctsubj_highsch_MOE
    Pctsubj_notHS_MOE
    Pctsubj_college_MOE
    Pctsubj_lingiso_MOE
    Pct_noEngl_MOE
    Pct_be150pov_MOE
    Pctsubj_belowpov_MOE
    Pctsubj_unemploy_MOE
    Pct_same_house_MOE
    Pct_from_within_co_MOE
    Pct_from_within_st_MOE
    Pct_from_within_us_MOE
    / weight=Totpop;
run;
/* Simpler descriptive stats for MOEs for Excel */
title 'N, mean, and StdDev for MOEs - by state (weighted by tract population)';
proc means data=CensSAS.Tract_Attributes_clean nolabels n mean ;
    by STUSAB;
   var
    Pct_sampled
    Pct_nonwhite_MOE
    Pct_Hispanic_MOE
    Pct_minority_MOE
    Pct_forborn_MOE
    Pctsubj_highsch_MOE
    Pctsubj_notHS_MOE
    Pctsubj_college_MOE
    Pctsubj_lingiso_MOE
    Pct_noEngl_MOE
    Pct_be150pov_MOE
    Pctsubj_belowpov_MOE
    Pctsubj_unemploy_MOE
    Pct_same_house_MOE
    Pct_from_within_co_MOE
    Pct_from_within_st_MOE
    Pct_from_within_us_MOE
    / weight=Totpop;
run;

ods pdf close;

