/* Summarize calculated tract attribute data by state */

options sysprintfont=("Courier New" 8) leftmargin=0.75in nocenter;

/* Specify data path here for portability: */
%let pathsas=J:\Census_Stuff\ACS2011_5yr\;
%let pathpdf=J:\Census_Stuff\ACS2011_5yr\SASRpts\;

%let obslimit=;
/* %let obslimit=obs=10000; /* For debugging */

libname CensSAS "&pathsas.SASData";
ods pdf file="&pathpdf.SAS51_SumByState_Tract_Attributes.pdf" uniform;

proc sort data=CensSAS.Tract_Attributes_clean;
    by STUSAB STATE;
run;

/* Statistics about the tracts in each state */
title 'Statistics about the tracts in each state';
proc means data=CensSAS.Tract_Attributes_clean MIN P10 MEAN P90 MAX STD noprint;
    by STUSAB STATE;
    var Totpop;
    OUTPUT OUT=tract_stats
        MIN = Totpop_min
        P5 = Totpop_10th_pctile
        MEAN = Totpop_mean
        P95 = Totpop_90th_pctile
        MAX = Totpop_max
        STD = Totpop_std
        / noinherit;
run;
proc means data=CensSAS.Tract_Attributes_clean MIN P10 MEAN P90 MAX STD noprint;
    /* by STUSAB STATE; */
    var Totpop;
    OUTPUT OUT=tract_stats_us
        MIN = Totpop_min
        P5 = Totpop_10th_pctile
        MEAN = Totpop_mean
        P95 = Totpop_90th_pctile
        MAX = Totpop_max
        STD = Totpop_std
        / noinherit;
run;
data tract_stats_both;
    set tract_stats tract_stats_us;
    if STUSAB = '' then State_US = "US Total";
    else State_US = STUSAB;
run;
proc print split='_' STYLE(TABLE)=[rules=groups padding=0pt];
    id State_US;
    var _FREQ_ Totpop_min Totpop_10th_pctile
        Totpop_mean Totpop_90th_pctile Totpop_max Totpop_std;
    label _FREQ_ = 'Number of tracts';
    format Totpop_mean Totpop_std 8.1;
run;

/* Create summary dataset (means are weighted by tract population) */
proc means data=CensSAS.Tract_Attributes_clean N MEAN /* STD MIN MAX */ noprint ;
    by STUSAB STATE;
    var Totpop Popsamps;    /* Not weighted */
    var                     /* Weighted by Totpop */
        Pct_sampled
        Pct_nonwhite        Pct_nonwhite_MOE
        Pct_Hispanic        Pct_Hispanic_MOE
        Pct_minority        Pct_minority_MOE
        Pct_forborn         Pct_forborn_MOE
        Pctsubj_highsch     Pctsubj_highsch_MOE
        Pctsubj_notHS       Pctsubj_notHS_MOE
        Pctsubj_college     Pctsubj_college_MOE
        Pctsubj_lingiso     Pctsubj_lingiso_MOE
        Pct_noEngl          Pct_noEngl_MOE
        Pct_be150pov        Pct_be150pov_MOE
        Pctsubj_belowpov    Pctsubj_belowpov_MOE
        Pctsubj_unemploy    Pctsubj_unemploy_MOE
        Pct_same_house      Pct_same_house_MOE
        Pct_from_within_co  Pct_from_within_co_MOE
        Pct_from_within_st  Pct_from_within_st_MOE
        Pct_from_within_us  Pct_from_within_us_MOE
        / weight=Totpop;
    OUTPUT OUT=CensSAS.Tract_Attributes_SumByState
    SUM (Totpop Popsamps) =
    MEAN (
        Pct_sampled
        Pct_nonwhite        Pct_nonwhite_MOE
        Pct_Hispanic        Pct_Hispanic_MOE
        Pct_minority        Pct_minority_MOE
        Pct_forborn         Pct_forborn_MOE
        Pctsubj_highsch     Pctsubj_highsch_MOE
        Pctsubj_notHS       Pctsubj_notHS_MOE
        Pctsubj_college     Pctsubj_college_MOE
        Pctsubj_lingiso     Pctsubj_lingiso_MOE
        Pct_noEngl          Pct_noEngl_MOE
        Pct_be150pov        Pct_be150pov_MOE
        Pctsubj_belowpov    Pctsubj_belowpov_MOE
        Pctsubj_unemploy    Pctsubj_unemploy_MOE
        Pct_same_house      Pct_same_house_MOE
        Pct_from_within_co  Pct_from_within_co_MOE
        Pct_from_within_st  Pct_from_within_st_MOE
        Pct_from_within_us  Pct_from_within_us_MOE
        ) =;
run;
data CensSAS.Tract_Attributes_SumByState;
    set CensSAS.Tract_Attributes_SumByState;
    label
        _FREQ_ = 'Number of tracts'
        Totpop = 'Sum of tract populations'
        Popsamps = 'Sum of tract samples'
        ;
    drop _TYPE_;
    rename _FREQ_ = Numtracts;
run;

/* State summary statistics of tract-level MOEs - range of values by state */
title 'State summary statistics of tract-level MOEs - range of values by state';
proc means data=CensSAS.Tract_Attributes_SumByState nolabels n min mean max stddev cv nmiss ;
   var
    Pct_sampled
    Pct_nonwhite_MOE
    Pct_Hispanic_MOE
    Pct_minority_MOE
    Pct_forborn_MOE
    Pctsubj_notHS_MOE
    Pctsubj_college_MOE
    Pctsubj_lingiso_MOE
    Pct_noEngl_MOE
    Pct_be150pov_MOE
    Pctsubj_belowpov_MOE
    Pctsubj_unemploy_MOE
    Pct_same_house_MOE
    Pct_from_within_co_MOE
    Pct_from_within_st_MOE
    Pct_from_within_us_MOE
    ;
run;

/* Correlations between the measures and their MOEs */
title 'State level correlations between the estimates, MOEs';
proc corr data=CensSAS.Tract_Attributes_SumByState /* noprob nosimple */
    outp=corrout noprint;
    var
      Pct_nonwhite
      Pct_Hispanic
      Pct_minority
      Pct_forborn
      Pctsubj_highsch
      Pctsubj_notHS
      Pctsubj_college
      Pctsubj_lingiso
      Pct_noEngl
      Pct_be150pov
      Pctsubj_belowpov
      Pctsubj_unemploy
      Pct_same_house
      Pct_from_within_co
      Pct_from_within_st
      Pct_from_within_us
      ;
    with
      Pct_nonwhite_MOE
      Pct_Hispanic_MOE
      Pct_minority_MOE
      Pct_forborn_MOE
      Pctsubj_highsch_MOE
      Pctsubj_notHS_MOE
      Pctsubj_college_MOE
      Pctsubj_lingiso_MOE
      Pct_noEngl_MOE
      Pct_be150pov_MOE
      Pctsubj_belowpov_MOE
      Pctsubj_unemploy_MOE
      Pct_same_house_MOE
      Pct_from_within_co_MOE
      Pct_from_within_st_MOE
      Pct_from_within_us_MOE
      ;
run;
data corrout_MOE;
    set corrout;
    length varEst varMOE $30;
    if _TYPE_ = 'CORR';
    if _NAME_ = 'Pct_nonwhite_MOE' then do;
        varEst =  'Pct_nonwhite';     varMOE='Pct_nonwhite_MOE';     corrMOE=Pct_nonwhite; end;
    if _NAME_ = 'Pct_Hispanic_MOE' then do;
        varEst =  'Pct_Hispanic';     varMOE='Pct_Hispanic_MOE';     corrMOE=Pct_Hispanic; end;
    if _NAME_ = 'Pct_minority_MOE' then do;
        varEst =  'Pct_minority';     varMOE='Pct_minority_MOE';     corrMOE=Pct_minority; end;
    if _NAME_ = 'Pct_forborn_MOE' then do;
        varEst =  'Pct_forborn';      varMOE='Pct_forborn_MOE';      corrMOE=Pct_forborn; end;
    if _NAME_ = 'Pctsubj_highsch_MOE' then do;
        varEst =  'Pctsubj_highsch';  varMOE='Pctsubj_highsch_MOE';  corrMOE=Pctsubj_highsch; end;
    if _NAME_ = 'Pctsubj_notHS_MOE' then do;
        varEst =  'Pctsubj_notHS';    varMOE='Pctsubj_notHS_MOE';    corrMOE=Pctsubj_notHS; end;
    if _NAME_ = 'Pctsubj_college_MOE' then do;
        varEst =  'Pctsubj_college';  varMOE='Pctsubj_college_MOE';  corrMOE=Pctsubj_college; end;
    if _NAME_ = 'Pctsubj_lingiso_MOE' then do;
        varEst =  'Pctsubj_lingiso';  varMOE='Pctsubj_lingiso_MOE';  corrMOE=Pctsubj_lingiso; end;
    if _NAME_ = 'Pct_noEngl_MOE' then do;
        varEst =  'Pct_noEngl';       varMOE='Pct_noEngl_MOE';       corrMOE=Pct_noEngl; end;
    if _NAME_ = 'Pct_be150pov_MOE' then do;
        varEst =  'Pct_be150pov';     varMOE='Pct_be150pov_MOE';     corrMOE=Pct_be150pov; end;
    if _NAME_ = 'Pctsubj_belowpov_MOE' then do;
        varEst =  'Pctsubj_belowpov'; varMOE='Pctsubj_belowpov_MOE'; corrMOE=Pctsubj_belowpov; end;
    if _NAME_ = 'Pctsubj_unemploy_MOE' then do;
        varEst =  'Pctsubj_unemploy'; varMOE='Pctsubj_unemploy_MOE'; corrMOE=Pctsubj_unemploy; end;
    if _NAME_ = 'Pct_same_house_MOE' then do;
        varEst =  'Pct_same_house';   varMOE='Pct_same_house_MOE';   corrMOE=Pct_same_house; end;
    if _NAME_ = 'Pct_from_within_co_MOE' then do;
        varEst =  'Pct_from_within_co'; varMOE='Pct_from_within_co_MOE'; corrMOE=Pct_from_within_co; end;
    if _NAME_ = 'Pct_from_within_st_MOE' then do;
        varEst =  'Pct_from_within_st'; varMOE='Pct_from_within_st_MOE'; corrMOE=Pct_from_within_st; end;
    if _NAME_ = 'Pct_from_within_us_MOE' then do;
        varEst =  'Pct_from_within_us'; varMOE='Pct_from_within_us_MOE'; corrMOE=Pct_from_within_us; end;
    keep varEst varMOE corrMOE;
run;
proc print noobs;
run;

/* State level horizontal bar charts */
title 'State level horizontal bar charts';
proc chart data=CensSAS.Tract_Attributes_SumByState;
    hbar
        Pct_sampled
        Pct_nonwhite_MOE
        Pct_Hispanic_MOE
        Pct_minority_MOE
        Pct_forborn_MOE
        Pctsubj_notHS_MOE
        Pctsubj_college_MOE
        Pctsubj_lingiso_MOE
        Pct_noEngl_MOE
        Pct_be150pov_MOE
        Pctsubj_belowpov_MOE
        Pctsubj_unemploy_MOE
        Pct_same_house_MOE
        Pct_from_within_co_MOE
        Pct_from_within_st_MOE
        Pct_from_within_us_MOE
    / missing midpoints = 0 to 20 by 1;
run;

/* Add rank variables for the most accurate MOEs */
proc rank data=CensSAS.Tract_Attributes_SumByState
        out=CensSAS.Tract_Attributes_SumByState descending ;
    var Pct_sampled; /* rank descending - more sampling is better */
    ranks Pct_sampled_rank ;
run;
proc rank data=CensSAS.Tract_Attributes_SumByState
        out=CensSAS.Tract_Attributes_SumByState /* descending */ ;
    var             /* rank ascending - smaller MOEs are better */
        Pct_nonwhite_MOE
        Pct_Hispanic_MOE
        Pct_minority_MOE
        Pctsubj_notHS_MOE
        Pctsubj_college_MOE
        Pct_forborn_MOE
        Pctsubj_lingiso_MOE
        Pct_noEngl_MOE
        Pctsubj_belowpov_MOE
        Pctsubj_unemploy_MOE
        Pct_same_house_MOE
        Pct_from_within_co_MOE
        Pct_from_within_st_MOE
        Pct_from_within_us_MOE
        ;
    ranks
        Pct_nonwhite_MOE_rank
        Pct_Hispanic_MOE_rank
        Pct_minority_MOE_rank
        Pctsubj_notHS_MOE_rank
        Pctsubj_college_MOE_rank
        Pct_forborn_MOE_rank
        Pctsubj_lingiso_MOE_rank
        Pct_noEngl_MOE_rank
        Pctsubj_belowpov_MOE_rank
        Pctsubj_unemploy_MOE_rank
        Pct_same_house_MOE_rank
        Pct_from_within_co_MOE_rank
        Pct_from_within_st_MOE_rank
        Pct_from_within_us_MOE_rank
        ;
run;

/* Add min, mean, max of the ranks */
data CensSAS.Tract_Attributes_SumByState;
    set CensSAS.Tract_Attributes_SumByState;
    rank_min = min(
        Pct_sampled_rank,
        Pct_nonwhite_MOE_rank,
        Pct_Hispanic_MOE_rank,
        Pct_minority_MOE_rank,
        Pctsubj_notHS_MOE_rank,
        Pctsubj_college_MOE_rank,
        Pct_forborn_MOE_rank,
        Pctsubj_lingiso_MOE_rank,
        Pct_noEngl_MOE_rank,
        Pctsubj_belowpov_MOE_rank,
        Pctsubj_unemploy_MOE_rank,
        Pct_same_house_MOE_rank,
        Pct_from_within_co_MOE_rank,
        Pct_from_within_st_MOE_rank,
        Pct_from_within_us_MOE_rank
        );
    rank_mean = mean(
        Pct_sampled_rank,
        Pct_nonwhite_MOE_rank,
        Pct_Hispanic_MOE_rank,
        Pct_minority_MOE_rank,
        Pctsubj_notHS_MOE_rank,
        Pctsubj_college_MOE_rank,
        Pct_forborn_MOE_rank,
        Pctsubj_lingiso_MOE_rank,
        Pct_noEngl_MOE_rank,
        Pctsubj_belowpov_MOE_rank,
        Pctsubj_unemploy_MOE_rank,
        Pct_same_house_MOE_rank,
        Pct_from_within_co_MOE_rank,
        Pct_from_within_st_MOE_rank,
        Pct_from_within_us_MOE_rank
        );
    rank_max = max(
        Pct_sampled_rank,
        Pct_nonwhite_MOE_rank,
        Pct_Hispanic_MOE_rank,
        Pct_minority_MOE_rank,
        Pctsubj_notHS_MOE_rank,
        Pctsubj_college_MOE_rank,
        Pct_forborn_MOE_rank,
        Pctsubj_lingiso_MOE_rank,
        Pct_noEngl_MOE_rank,
        Pctsubj_belowpov_MOE_rank,
        Pctsubj_unemploy_MOE_rank,
        Pct_same_house_MOE_rank,
        Pct_from_within_co_MOE_rank,
        Pct_from_within_st_MOE_rank,
        Pct_from_within_us_MOE_rank
        );
    format rank_mean 5.1;
run;

/* Turn off use of labels for upcoming print output */
options nolabel;

/* Print states in order by rank_mean */
title 'State ranks of accuracy - lower ranks are more accurate';
proc sort data=CensSAS.Tract_Attributes_SumByState;
    by rank_mean;
run;
proc print data=CensSAS.Tract_Attributes_SumByState
        split='_' STYLE(TABLE)=[rules=groups padding=0pt];
    id STUSAB;
    var
        rank_mean
        rank_min
        rank_max
        Pct_sampled
        Pct_sampled_rank
        Pct_nonwhite_MOE
        Pct_nonwhite_MOE_rank
        Pct_Hispanic_MOE_rank
        Pct_minority_MOE_rank
        Pctsubj_notHS_MOE_rank
        Pctsubj_college_MOE_rank
        ;
run;
proc print data=CensSAS.Tract_Attributes_SumByState
        split='_' STYLE(TABLE)=[rules=groups padding=0pt];
    id STUSAB;
    var
        rank_mean
        Pct_forborn_MOE_rank
        Pctsubj_lingiso_MOE_rank
        Pct_noEngl_MOE_rank
        Pctsubj_belowpov_MOE_rank
        Pctsubj_unemploy_MOE_rank
        Pct_same_house_MOE_rank
        Pct_from_within_co_MOE_rank
        Pct_from_within_st_MOE_rank
        Pct_from_within_us_MOE_rank
        ;
run;

/* Leave the data set sorted by state */
proc sort data=CensSAS.Tract_Attributes_SumByState;
    by STUSAB STATE;
run;

ods pdf close;

