* Example uses table C17002 (Income to Poverty Ratio) which corresponds to sequence number 46
* and positions 219-226 (there are 220 actual estimates and margins of error for that 
* sequence number and 6 general variables to indicate table, logical record number, etc). 
* Position 226 is the last variable for that sequence number.
* - Laura Soloway, NY Cancer Registry
* Details at: http://www.sascommunity.org/wiki/Downloading_American_Community_Survey_5_year_data_into_a_workable_SAS_format
 
 libname acs "C:\acs "; *this is where you will put your permanent datasets;
 %let sn=046; *this is the sequence number of the table you want;
 %let startpos=219; *this is the start position of the variables you want within the sequence number from the lookup table;
 %let endpos=226; *this is the end position of the variables you want within the sequence number from the lookup table;
 %let last=226; *this is the last variable position in the sequence number you have chosen from the lookup table;
 
 
 
 *create a dataset with the state abbreviations and Fips codes;
 
 proc sort data=sashelp.zipcode nodupkey out=state;
 by state statecode;
 run;
 
 data state;
 set state;
 keep state statecode;
 if state le 56;
 run;
 
 
 
 * import datasets for each state and for estimate (est) and margin of error(moe), and append states together;
 
 %macro num;	
 /*change number in datafile to indicate sequence number of table you want, from the sequence number and lookup table*/;
 PROC IMPORT DATAFILE= " C:\acs\e20095&statem.0&sn000.txt " OUT= work.est&j DBMS=CSV REPLACE ;getnames=no;DATAROW=1;
 RUN;
 proc datasets nolist force;
 append out=est1 data=est&j;
 quit;
 run;
 
 PROC IMPORT DATAFILE= " C:\acs\m20095&statem.0&sn000.txt " OUT= work.moe&j DBMS=CSV REPLACE; getnames=no; DATAROW=1; 	
 RUN;
 proc datasets nolist force;
 append out=moe1 data=moe&j;
 quit;
 run;
 %mend;
 
 
 %macro states;
 %do j=1 %to 56;
 data _null_;
 set state;
 if _n_=&j;
 call symputx('statem', statecode);
 %num;
 run;
 %end;
 %mend;
 
 %states;
 
 
 
 *make variables consistent in order to merge estimates (est) and margin of error (moe) files ;
 
 data acs.aktotalest;
 set est1;
 state=upcase(var3);
 rename var6=logrecnum;
 run;
 
 
 data acs.aktotalmoe;
 set moe1;
 state=upcase(var3);
 rename var6=logrecnum;
 run;
 
 
 proc sort data=acs.aktotalmoe noduprecs out=acstotalmoe;
 by state var5 logrecnum;
 run;
 
 
 proc sort data=acs.aktotalest noduprecs out=acstotalest;
 by state var5 logrecnum;
 run; 
 
 
 %macro rename;
 proc datasets library=work;
 modify acstotalmoe;
 rename var2=mvar2 ;
 rename %do i=7 %to &last;
 var&i=mvar&i.
 %end;
 ;
 run; quit;
 %mend;
 
 
 %rename;		   
 proc sort data=acstotalest;
 by state logrecnum;
 run;
 
 proc sort data=acstotalmoe;
 by state logrecnum;
 run;
 
 data estmoe;
 merge acstotalest (in=a) acstotalmoe (in=c);
 by state logrecnum;
 run;
 
 
 
 *import the geographic files and append them together.  This would be the same for any table you download for census tract information.;
 
 %macro geography;
 data	geo;
	infile "D:\acs\downloaded acs files\g20095&statem..txt" delimiter = ' ' MISSOVER DSD lrecl=32767 ;
	input 
	@7 state $2.
	@9 sumlev $3.
	@12 geocom $2.
	@14 logrecnum1 $7.
	@26 state_fips $2.
	@28 county $3.
	@36 place $5.
	@41 tract $6.
	@47 region $1.
	;
	run;
 
 data geo&j;
	set geo;
	if tract='' then delete;
	if place='';
	if region='';
	run;
 
 proc append base=geo1 data=geo&j force;
 quit;
 run;
 
 proc sort data=geo1;
 by state county tract;
 run;
 %mend;
 
 %macro geog1;
 %do j=1 %to 56;
 data _null_;
 set state;
 if _n_=&j;
 call symputx('statem', statecode);
 %geography;
 run;
 %end;
 %mend;
 
 %geog1;
 
 
 proc sort data=geo1;
 by state county tract;
 run;
 
 data acsgeototal (drop=logrecnum1);
 set geo1;
 by state county tract;
 if first.tract;
 logrecnum=logrecnum1*1;
 run;
 
 
 
 *Merge geographic files and estimate and margin of error files;
 
 proc sort data=estmoe;
 by state logrecnum;
 run;
 
 
 proc sort data=acsgeototal;
 by state logrecnum;
 run;
 
 
 data estmoegeo;
 merge acsgeototal (in=a) estmoe (in=b);
 by state logrecnum;
 if a;
 run;
 
 
 proc sort data=estmoegeo;
 by state county tract;
 run;
 
 
 
 
 *Restrict the dataset to just the needed variables;
 
 data estmoegeo1 (keep=state_fips county tract logrecnum1 var&startpos-var&endpos mvar&startpos-mvar&endpos);
 set estmoegeo;
 by state county tract;
 if first.tract;
 run;
 
 
 *this is the final dataset for the ACS data Income to Poverty Ratio table.  Variable names will change for different tables that are selected;
 
 PROC DATASETS LIBRARY = WORK;
 MODIFY estmoegeo1;
 RENAME var219= total_pop var220 = _under50
 
 var221 = _50to99
 var222 = _100to124
 var223 = _125to149
 var224 = _150to184
 var225 = _185to199
 var226 = _200over
 mvar219 = moe_total_pop
 mvar220 = moe_000to050
 mvar221 = moe_50to99
 mvar222 = moe_100to124
 mvar223 = moe_125to149
 mvar224 = moe_150to184
 mvar225 = moe_185to199
 mvar226 = moe_200over
 ;
 LABEL total_pop=estimate total pop
 _under50 = under 50%
 _50to99 = 50% to 99%
 _100to124 = 100% to 124%
 _125to149 = 125% to 149%
 _150to184 = 150% to 184%
 _185to199 = 185% to 199%
 _200over = over 200%
 moe_total_pop= margin of error total pop
 moe_000to050 = margin of error under 50%
 moe_50to99 = margin of error 50% to 99%
 moe_100to124 = margin of error 100% to 124%
 moe_125to149 = margin of error 125% to 149%
 moe_150to184 = margin of error 150% to 184%
 moe_185to199 = margin of error 185% to 199%
 moe_200over = margin of error over 200%
 ;
 QUIT; RUN;
 
 
 Data acs.acsinctopovratio1;
 Set estmoegeo1;
 geoid=cat(state_fips, county, tract);
 Run;
 
 
 *this should say zero cases deleted;
 
 proc sort data=acs.acsinctopovratio1 nodupkey out=checkacs;
 by geoid;
 run;